aboutsummaryrefslogtreecommitdiff
path: root/internal/gitutil/module.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/gitutil/module.go')
-rw-r--r--internal/gitutil/module.go48
1 files changed, 25 insertions, 23 deletions
diff --git a/internal/gitutil/module.go b/internal/gitutil/module.go
index f34e2961..f550f865 100644
--- a/internal/gitutil/module.go
+++ b/internal/gitutil/module.go
@@ -12,23 +12,25 @@ import (
//
// NOTE: All methods are sorted in alphabetical order.
type ModuleStore interface {
- // AddRemote adds a new remote to the repository in given path.
- RepoAddRemote(repoPath, name, url string, opts ...git.AddRemoteOptions) error
- // RepoDiffNameOnly returns a list of changed files between base and head revisions
+ // RemoteAdd adds a new remote to the repository in given path.
+ RemoteAdd(repoPath, name, url string, opts ...git.RemoteAddOptions) error
+ // DiffNameOnly returns a list of changed files between base and head revisions
// of the repository in given path.
- RepoDiffNameOnly(repoPath, base, head string, opts ...git.DiffNameOnlyOptions) ([]string, error)
- // RepoLog returns a list of commits in the state of given revision of the repository
- // in given path. The returned list is in reverse chronological order.
- RepoLog(repoPath, rev string, opts ...git.LogOptions) ([]*git.Commit, error)
- // RepoMergeBase returns merge base between base and head revisions of the repository
- // in given path.
- RepoMergeBase(repoPath, base, head string, opts ...git.MergeBaseOptions) (string, error)
- // RepoRemoveRemote removes a remote from the repository in given path.
- RepoRemoveRemote(repoPath, name string, opts ...git.RemoveRemoteOptions) error
+ DiffNameOnly(repoPath, base, head string, opts ...git.DiffNameOnlyOptions) ([]string, error)
+ // Log returns a list of commits in the state of given revision of the
+ // repository in given path. The returned list is in reverse chronological
+ // order.
+ Log(repoPath, rev string, opts ...git.LogOptions) ([]*git.Commit, error)
+ // MergeBase returns merge base between base and head revisions of the
+ // repository in given path.
+ MergeBase(repoPath, base, head string, opts ...git.MergeBaseOptions) (string, error)
+ // RemoteRemove removes a remote from the repository in given path.
+ RemoteRemove(repoPath, name string, opts ...git.RemoteRemoveOptions) error
// RepoTags returns a list of tags of the repository in given path.
RepoTags(repoPath string, opts ...git.TagsOptions) ([]string, error)
- // GetPullRequestMeta gathers pull request metadata based on given head and base information.
+ // PullRequestMeta gathers pull request metadata based on given head and base
+ // information.
PullRequestMeta(headPath, basePath, headBranch, baseBranch string) (*PullRequestMeta, error)
// ListTagsAfter returns a list of tags "after" (exclusive) given tag.
ListTagsAfter(repoPath, after string, limit int) (*TagsPage, error)
@@ -37,24 +39,24 @@ type ModuleStore interface {
// module holds the real implementation.
type module struct{}
-func (module) RepoAddRemote(repoPath, name, url string, opts ...git.AddRemoteOptions) error {
- return git.RepoAddRemote(repoPath, name, url, opts...)
+func (module) RemoteAdd(repoPath, name, url string, opts ...git.RemoteAddOptions) error {
+ return git.RemoteAdd(repoPath, name, url, opts...)
}
-func (module) RepoDiffNameOnly(repoPath, base, head string, opts ...git.DiffNameOnlyOptions) ([]string, error) {
- return git.RepoDiffNameOnly(repoPath, base, head, opts...)
+func (module) DiffNameOnly(repoPath, base, head string, opts ...git.DiffNameOnlyOptions) ([]string, error) {
+ return git.DiffNameOnly(repoPath, base, head, opts...)
}
-func (module) RepoLog(repoPath, rev string, opts ...git.LogOptions) ([]*git.Commit, error) {
- return git.RepoLog(repoPath, rev, opts...)
+func (module) Log(repoPath, rev string, opts ...git.LogOptions) ([]*git.Commit, error) {
+ return git.Log(repoPath, rev, opts...)
}
-func (module) RepoMergeBase(repoPath, base, head string, opts ...git.MergeBaseOptions) (string, error) {
- return git.RepoMergeBase(repoPath, base, head, opts...)
+func (module) MergeBase(repoPath, base, head string, opts ...git.MergeBaseOptions) (string, error) {
+ return git.MergeBase(repoPath, base, head, opts...)
}
-func (module) RepoRemoveRemote(repoPath, name string, opts ...git.RemoveRemoteOptions) error {
- return git.RepoRemoveRemote(repoPath, name, opts...)
+func (module) RemoteRemove(repoPath, name string, opts ...git.RemoteRemoveOptions) error {
+ return git.RemoteRemove(repoPath, name, opts...)
}
func (module) RepoTags(repoPath string, opts ...git.TagsOptions) ([]string, error) {